==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/zh_CN.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "链接：",
    "Password:" : "密码 :",
    "Generating system report failed." : "生成系统报告失败.",
    "Subscription notifications" : "订阅通知",
    "Could not create folder \"System information\" to store generated report." : "无法新建 \"System information\" 文件夹来存储生成的报告.",
    "Could not create file \"%s\" to store generated report." : "无法创建文件 \"%s\" 用于存储报告.",
    "Could not share file \"%s\"." : "无法分享文件 \"%s\".",
    "Nextcloud Subscription" : "Nextcloud 订阅",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "您的服务器没有 Nextcloud 订阅或者您的订阅已到期.",
    "Your Nextcloud Subscription has expired!" : "您的 Nextcloud 订阅已到期! ",
    "Your server has no Nextcloud Subscription or your Subscription has expired" : "您的服务器没有 Nextcloud 订阅或者您的订阅已到期",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "您的 Nextcloud 服务器不受 Nextcloud 企业版订阅的支持",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "当您遇到了问题导致了您的服务器不再正常工作，使得职员无法分享文件或者消费者们无法上传、下载文件时，您不必依赖网络搜索或咨询社交媒体和论坛上的志愿者来寻找解决方案。您可以直接接触到我们经验丰富的工程师来帮助您追溯并解决问题。",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "您和能够提供保密安全信息，风险回避，维护及更新服务的供应商达成了协议。",
    "Support" : "支持",
    "Basic subscription" : "基础订阅",
    "Standard subscription" : "标准订阅",
    "Premium subscription" : "豪华订阅",
    "Subscription" : "订阅",
    "Over subscription limit" : "超过订阅限制",
    "Valid subscription" : "有效的订阅",
    "Expired subscription" : "过期的订阅",
    "Subscription key:" : "订阅密钥:",
    "_Expires in %n year_::_Expires in %n years_" : ["将在 %n 年后过期"],
    "_Expires in %n month_::_Expires in %n months_" : ["将在 %n 月后过期"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["将在 %n 周后过期"],
    "_Expires in %n day_::_Expires in %n days_" : ["将在 %n 天后过期"],
    "Update subscription key" : "更新订阅密钥",
    "System information" : "系统信息",
    "Generate system report" : "生成系统报告",
    "No active enterprise subscription" : "无激活的企业版订阅",
    "Commmunity support" : "社区支持",
    "Forum" : "论坛",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud 是一个被活跃社区支持的免费软件. 您可以注册论坛后提问并与其他人交流.",
    "Nextcloud forum" : "Nextcloud 论坛",
    "GitHub" : "Github",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud 使用 Github 作为协同工作平台. 您可以在那里直接提交错误报告.",
    "Nextcloud at GitHub" : "GitHub 上的 Nextcloud",
    "Chat" : "聊天",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "在 Freenode 上通过我们的 IRC 频道 #nextcloud 与我们进行交流.",
    "Open chat" : "开启聊天",
    "Subscription key" : "订阅密钥",
    "Set subscription key" : "设置订阅密钥",
    "News" : "新闻"
},
"nplurals=1; plural=0;");

==> nextcloud-14.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/zh_CN.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "链接：",
    "Password:" : "密码 :",
    "Generating system report failed." : "生成系统报告失败.",
    "Subscription notifications" : "订阅通知",
    "Could not create folder \"System information\" to store generated report." : "无法新建 \"System information\" 文件夹来存储生成的报告.",
    "Could not create file \"%s\" to store generated report." : "无法创建文件 \"%s\" 用于存储报告.",
    "Could not share file \"%s\"." : "无法共享文件 \"%s\".",
    "Nextcloud Subscription" : "Nextcloud 订阅",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "您的服务器没有 Nextcloud 订阅或者您的订阅已到期.",
    "Your Nextcloud Subscription has expired!" : "您的 Nextcloud 订阅已到期! ",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "您的 Nextcloud 服务器不受 Nextcloud 企业版订阅的支持",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "当您遇到了问题导致了您的服务器不再正常工作，使得职员无法共享文件或者消费者们无法上传、下载文件时，您不必依赖网络搜索或咨询社交媒体和论坛上的志愿者来寻找解决方案。您可以直接接触到我们经验丰富的工程师来帮助您追溯并解决问题。",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "您和能够提供保密安全信息，风险回避，维护及更新服务的供应商达成了协议。",
    "Support" : "支持",
    "Basic subscription" : "基础订阅",
    "Standard subscription" : "标准订阅",
    "Premium subscription" : "豪华订阅",
    "Subscription" : "订阅",
    "Over subscription limit" : "超过订阅限制",
    "Valid subscription" : "有效的订阅",
    "Expired subscription" : "过期的订阅",
    "Subscription key:" : "订阅密钥:",
    "_Expires in %n year_::_Expires in %n years_" : ["将在 %n 年后过期"],
    "_Expires in %n month_::_Expires in %n months_" : ["将在 %n 月后过期"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["将在 %n 周后过期"],
    "_Expires in %n day_::_Expires in %n days_" : ["将在 %n 天后过期"],
    "Update subscription key" : "更新订阅密钥",
    "System information" : "系统信息",
    "Generate system report" : "生成系统报告",
    "No active enterprise subscription" : "无激活的企业版订阅",
    "Commmunity support" : "社区支持",
    "Forum" : "论坛",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud 是一个被活跃社区支持的免费软件. 您可以注册论坛后提问并与其他人交流.",
    "Nextcloud forum" : "Nextcloud 论坛",
    "GitHub" : "Github",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud 使用 Github 作为协同工作平台. 您可以在那里直接提交错误报告.",
    "Nextcloud at GitHub" : "GitHub 上的 Nextcloud",
    "Chat" : "聊天",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "在 Freenode 上通过我们的 IRC 频道 #nextcloud 与我们进行交流.",
    "Open chat" : "开启聊天",
    "Subscription key" : "订阅密钥",
    "Set subscription key" : "设置订阅密钥",
    "News" : "新闻"
},
"nplurals=1; plural=0;");
